.. only:: (format_html or format_latex)

    .. image:: /_images/logo_horizontal.png
        :alt: Powertools Technologies
        :height: 75px

tkmilan
=======

This is documentation for the tkmilan module.

.. todo:: Include a hero image here, a screenshot of the showcase.

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   :name: topindex

   development

   summary
   api

Other Pages
-----------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. todo:: Include these links on the regular TOC

Metadata
--------

Current Version: |version|

.. only:: debug

   Current Release: |release|

Built |today|
